@@ -70,8 +70,12 @@ class Logger:
 
     group = [TRACE, DEBUG, INFO, SILENT]
 
-    def __init__(self, prefix, level, handler=None, skip_repeat: bool = False):
+    def __init__(self, prefix, level, handler=None, skip_repeat: bool = False, timestamp: str = "%Y%m%d %H:%M:%S"):
         self.prefix = prefix
+        if not self.prefix:
+            self.prefix = ''
+        else:
+            self.prefix = f'[{self.prefix}]'
 
         if not isinstance(level, LoggerLevel):
             raise TypeError(f'Error log level type: {type(level)}')
@@ -79,11 +83,12 @@ class Logger:
             raise ValueError('Log level error')
 
         self.level = level
-        if handler is not None and not callable(handler):
+        if handler and not callable(handler):
             raise TypeError('Handler must is callable!!')
         self.handler = handler
         self.skip_repeat = skip_repeat
         self.last_msg = None
+        self.timestamp = timestamp
 
     def info(self, *msg):
         self.log(Logger.INFO, *msg)
@@ -119,12 +124,13 @@ class Logger:
         msg = [f' {_merge(x)}' for x in msg]
         msg.insert(0, des)
 
-        if self.prefix is None:
-            total_message = f'[{strftime("%Y%m%d %H:%M:%S")}] {"".join(msg)}'
-        else:
-            total_message = f'[{strftime("%Y%m%d %H:%M:%S")}][{self.prefix}] {"".join(msg)}'
+        timestamp = ''
+        if self.timestamp:
+            timestamp = f'[{strftime(self.timestamp)}]'
 
-        if self.handler is not None:
+        total_message = f'{timestamp}{self.prefix} {"".join(msg)}'.strip()
+
+        if self.handler:
             self.handler(total_message)
 
         with global_lock:
